Name:           iaito
Summary:        GUI for radare2 reverse engineering framework
Version:        5.8.8
%global         baserelease     3.2
%global         upversion       %{version}-beta
URL:            https://radare.org/n/iaito.html
VCS:            https://github.com/radareorg/iaito/

%bcond_without     releasetag

%global         gituser         radareorg
%global         gitname         iaito

%global         gitdate         20230620
%global         commit          1c984ae94b128e9f9c526cc418956801cd035d6e
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

%global         iaito_translations_gitdate      20221114
%global         iaito_translations_commit       e66b3a962a7fc7dfd730764180011ecffbb206bf
%global         iaito_translations__shortcommit %(c=%{iaito_translations_commit}; echo ${c:0:7})


%if %{with releasetag}
Release:    2%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
%else
Release:    2%{?dist}
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
%endif


License:        GPLv3 and CC-BY-SA and CC0

Source1:        https://github.com/radareorg/iaito-translations/archive/%{iaito_translations_commit}.tar.gz#/iaito-translations-git%{iaito_translations_gitdate}.tar.gz
Patch0:         iaito-5.8.8-norpath.patch

BuildRequires:  radare2-devel >= 5.6.8
BuildRequires:  make
BuildRequires:  gcc-c++
BuildRequires:  kf5-syntax-highlighting-devel
BuildRequires:  python3-devel
BuildRequires:  qt5-qtsvg-devel
BuildRequires:  file-devel
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib
BuildRequires:  graphviz-devel
BuildRequires:  qt5-linguist
%ifarch %{qt5_qtwebengine_arches}
BuildRequires:  qt5-qtwebengine-devel
%endif


BuildRequires:  python3-breathe
BuildRequires:  python3-recommonmark

Requires:       python3-jupyter-client
Requires:       python3-notebook
Requires:       hicolor-icon-theme

Provides:       r2cutter = %{version}-%{release}


%description
iaito is a Qt and C++ GUI for radare2.
It is the continuation of Cutter before the fork to keep radare2 as backend.
Its goal is making an advanced, customizable and FOSS reverse-engineering
platform while keeping the user experience at mind.
The iaito is created by reverse engineers for reverse engineers.
Focus on supporting latest version of radare2.
Recommend the use of system installed libraries/radare2.
Closer integration between r2 and the UI.

%package devel
Summary:        Development files for the iaito package
Requires:       %{name} = %{version}-%{release}

Provides:       r2cutter-devel = %{version}-%{release}

%description devel
Development files for the iaito package. See iaito package for more
information.


%prep
%if %{with releasetag}
%autosetup -p1 -n %{gitname}-%{version}
%else
%autosetup -p1 -n %{gitname}-%{commit}
sed -i -e "s|%{version}-git|%{version}|g;" configure configure.acr
%endif

[ -d src/translations ] || mkdir -p src/translations
tar --strip-component=1 -xvf %{SOURCE1} -C src/translations

sed -i Makefile -e '\@MAKE@s|-j4|%_smp_mflags|'

sed -i src/Iaito.pro \
    -e 's|^QMAKE_CXXFLAGS +=.*$|QMAKE_CXXFLAGS += %build_cxxflags\nQMAKE_LFLAGS += %build_ldflags|' \
    %{nil}

sed -i src/Iaito.pro -e 's|/usr/local|%_prefix|'

mkdir TMPBINDIR
cd TMPBINDIR
ln -sf %_bindir/qmake-qt5 qmake
ln -sf %_bindir/lrelease-qt5 lrelease
cd ..

%build
export PATH=$(pwd)/TMPBINDIR:$PATH

%configure
%make_build


%install
export PATH=$(pwd)/TMPBINDIR:$PATH
%make_install STRIP=true
make install-translations DESTDIR=%{?buildroot}


%find_lang %name --with-qt


%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.appdata.xml
desktop-file-validate %{buildroot}/%{_datadir}/applications/*.desktop


%files -f %{name}.lang
%{_bindir}/iaito
%dir %{_datadir}/iaito/
%dir %{_datadir}/iaito/translations
%{_datadir}/applications/*.desktop
%{_metainfodir}/*.appdata.xml
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_mandir}/man1/iaito.1*
%license COPYING src/img/icons/Iconic-LICENSE
%doc README.md


%changelog
* Tue Apr 23 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.8-2
- rebase to add ocs and ts macros

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.8.8-1
- initial build
